# wsidata

<p align="center">
    <picture align="center">
    <img src="https://raw.githubusercontent.com/rendeirolab/wsidata/main/assets/logo.svg" width="100px">
    </picture>
</p>
<p align="center">
  <i>Efficient data structures and IO for whole slide images analysis</i>
</p>


## Installation

```bash
pip install wsidata
```